@@ -9,31 +9,30 @@ def get_data(dataset, save_copy=False, profile = False):
       
     Description:
     ------------
-    This function loads the sample dataset available at pycaret git repository. To view
-    the full list of available datasets and their description, index can be called.
+    This function loads sample datasets that are available in the pycaret git 
+    repository. The full list of available datasets and their descriptions can
+    be viewed by calling index.
 
         Example
         -------
         data = get_data('index')
 
-        This will display the list of available datasets that can be loaded using 
-        get_data() function. For example to load credit dataset:
+        This will display the list of available datasets that can be loaded 
+        using the get_data() function. For example, to load the credit dataset:
         
-        credit_data = get_data('credit')
+        credit = get_data('credit')
         
     Parameters
     ----------
-    
     dataset : string 
     index value of dataset
     
     save_copy : bool, default = False
-    When set to true, it saves the copy of dataset in your local active directory.
+    When set to true, it saves a copy of the dataset to your local active directory.
     
     profile: bool, default = False
-    If set to true, it will display data profile for Exploratory Data Analysis in 
-    interactive HTML report. 
-    
+    If set to true, a data profile for Exploratory Data Analysis will be displayed 
+    in an interactive HTML report. 
     
     Returns:
     --------
@@ -44,9 +43,8 @@ def get_data(dataset, save_copy=False, profile = False):
     Warnings:
     ---------
     - Use of get_data() requires internet connection.
-    
-  
-       
+      
+         
     """
     
     import pandas as pd
@@ -59,6 +57,9 @@ def get_data(dataset, save_copy=False, profile = False):
     
     data = pd.read_csv(complete_address)
     
+    #create a copy for pandas profiler
+    data_for_profiling = data.copy()
+    
     if save_copy:
         save_name = str(dataset) + str(extension)
         data.to_csv(save_name)
@@ -69,7 +70,7 @@ def get_data(dataset, save_copy=False, profile = False):
     else:
         if profile:
             import pandas_profiling
-            pf = pandas_profiling.ProfileReport(data)
+            pf = pandas_profiling.ProfileReport(data_for_profiling)
             display(pf)
             
         else:
