@@ -766,6 +766,7 @@ def create_model(model=None,
     return model
 
 
+
 def assign_model(model,
                  verbose=True):
     
@@ -1259,7 +1260,6 @@ def plot_model(model = None,
     cf.set_config_file(offline=False, world_readable=True)
 
     
-    
     if plot == 'frequency':
         
         try:   
@@ -1286,7 +1286,7 @@ def plot_model(model = None,
 
                 title = str(topic_num) + ': ' + 'Top 100 words after removing stop words'
 
-                assigned_df = assign_model(model)
+                assigned_df = assign_model(model, verbose = False)
                 filtered_df = assigned_df.loc[assigned_df['Dominant_Topic'] == topic_num]
 
                 common_words = get_top_n_words(filtered_df[target_], n=100)
@@ -1319,7 +1319,7 @@ def plot_model(model = None,
             else:
 
                 title = str(topic_num) + ': ' + 'Word Count Distribution'
-                assigned_df = assign_model(model)
+                assigned_df = assign_model(model, verbose = False)
                 filtered_df = assigned_df.loc[assigned_df['Dominant_Topic'] == topic_num]
 
                 b = filtered_df[target_].apply(lambda x: len(str(x).split()))
@@ -1361,7 +1361,7 @@ def plot_model(model = None,
             else:
 
                 title = str(topic_num) + ': ' + 'Top 100 bigrams after removing stop words'
-                assigned_df = assign_model(model)
+                assigned_df = assign_model(model, verbose = False)
                 filtered_df = assigned_df.loc[assigned_df['Dominant_Topic'] == topic_num]
 
                 common_words = get_top_n_bigram(filtered_df[target_], 100)
@@ -1397,7 +1397,7 @@ def plot_model(model = None,
             else:
 
                 title = str(topic_num) + ': ' + 'Top 100 trigrams after removing stop words'
-                assigned_df = assign_model(model)
+                assigned_df = assign_model(model, verbose = False)
                 filtered_df = assigned_df.loc[assigned_df['Dominant_Topic'] == topic_num]            
                 common_words = get_top_n_trigram(filtered_df[target_], 100)
                 df3 = pd.DataFrame(common_words, columns = ['Text' , 'count'])
@@ -1431,7 +1431,7 @@ def plot_model(model = None,
 
             else: 
                 title = str(topic_num) + ': ' + 'Sentiment Polarity Distribution'
-                assigned_df = assign_model(model)
+                assigned_df = assign_model(model, verbose = False)
                 filtered_df = assigned_df.loc[assigned_df['Dominant_Topic'] == topic_num] 
                 sentiments = filtered_df[target_].map(lambda text: TextBlob(text).sentiment.polarity)
                 sentiments = pd.DataFrame(sentiments)
@@ -1466,7 +1466,7 @@ def plot_model(model = None,
         
     elif plot == 'tsne':
         
-        b = assign_model(model)
+        b = assign_model(model, verbose = False)
         b.dropna(axis=0, inplace=True) #droping rows where Dominant_Topic is blank
 
         c = []
@@ -1483,6 +1483,7 @@ def plot_model(model = None,
         X = pd.DataFrame(X_embedded)
         X['Dominant_Topic'] = b['Dominant_Topic']
         X.sort_values(by='Dominant_Topic', inplace=True)
+        X.dropna(inplace=True)
 
         import plotly.express as px
         df = X
@@ -1546,7 +1547,7 @@ def plot_model(model = None,
 
 
         kw_df = pd.DataFrame({'Topic': topic_name, 'Keyword' : keyword}).set_index('Topic')
-        ass_df = assign_model(model)
+        ass_df = assign_model(model, verbose = False)
         ass_df_pivot = ass_df.pivot_table(index='Dominant_Topic', values='Topic_0', aggfunc='count')
         df2 = ass_df_pivot.join(kw_df)
         df2 = df2.reset_index()
@@ -1601,7 +1602,7 @@ def plot_model(model = None,
 
             else:
 
-                assigned_df = assign_model(model)
+                assigned_df = assign_model(model, verbose = False)
                 filtered_df = assigned_df.loc[assigned_df['Dominant_Topic'] == topic_num] 
                 atext = " ".join(review for review in filtered_df[target_])
 
@@ -1875,24 +1876,27 @@ def tune_model(model=None,
     #pre-load libraries
     import pandas as pd
     import ipywidgets as ipw
+    from ipywidgets import Output
     from IPython.display import display, HTML, clear_output, update_display
     import datetime, time
 
     #progress bar
     max_steps = 25
-
     progress = ipw.IntProgress(value=0, min=0, max=max_steps, step=1 , description='Processing: ')
     display(progress)
-
+    
     timestampStr = datetime.datetime.now().strftime("%H:%M:%S")
 
     monitor = pd.DataFrame( [ ['Initiated' , '. . . . . . . . . . . . . . . . . .', timestampStr ], 
                              ['Status' , '. . . . . . . . . . . . . . . . . .' , 'Loading Dependencies'],
                              ['Step' , '. . . . . . . . . . . . . . . . . .',  'Initializing' ] ],
                               columns=['', ' ', '   ']).set_index('')
-
-    display(monitor, display_id = 'monitor')
-
+    
+    monitor_out = Output()
+    display(monitor_out)
+    
+    with monitor_out:
+        display(monitor, display_id = 'monitor')
 
     #General Dependencies
     from sklearn.linear_model import LogisticRegression
@@ -2041,10 +2045,14 @@ def tune_model(model=None,
                       title= 'Coherence Value and # of Topics', color='Metric')
 
         fig.update_layout(plot_bgcolor='rgb(245,245,245)')
-
-        clear_output()
-
+        
         fig.show()
+        
+        monitor = '' 
+        update_display(monitor, display_id = 'monitor')
+        
+        monitor_out.clear_output()
+        progress.close()
 
         best_k = np.array(sorted_df.head(1)['# Topics'])[0]
         best_m = round(np.array(sorted_df.head(1)['Score'])[0],4)
@@ -2248,9 +2256,13 @@ def tune_model(model=None,
         title= str(full_name) + ' Metrics and # of Topics'
         fig.update_layout(title={'text': title, 'y':0.95,'x':0.45,'xanchor': 'center','yanchor': 'top'})
 
-        clear_output()
-
         fig.show()
+        
+        monitor = ''
+        update_display(monitor, display_id = 'monitor')
+        
+        monitor_out.clear_output()
+        progress.close()
 
         best_k = np.array(sorted_df.head(1)['# Topics'])[0]
         best_m = round(np.array(sorted_df.head(1)[optimize])[0],4)
@@ -2494,8 +2506,13 @@ def tune_model(model=None,
                       title= str(full_name) + ' Metrics and # of Topics', color='Metric')
 
         fig.update_layout(plot_bgcolor='rgb(245,245,245)')
-        progress.value += 1 
-        clear_output()
+        progress.value += 1
+        
+        monitor = ''
+        update_display(monitor, display_id = 'monitor')
+        
+        monitor_out.clear_output()
+        progress.close()
 
         fig.show()
         best_k = np.array(sorted_df.head(1)['# Topics'])[0]
@@ -2511,6 +2528,7 @@ def tune_model(model=None,
 
 
 
+
 def evaluate_model(model):
     
     """
